%define SVNDATE   20140328
%define SVNREV    15376
%define SVNFATREV 67

%define OpenSSLversion 0.9.8w

# Secure boot enabled by default
%bcond_without secure
%if %{with secure}
%global BUILD_OPTIONS_X64 -D SECURE_BOOT_ENABLE
%endif

# Building a 32-bit image is disabled because it doesn't work for me
# (I only tested gcc -m32).
%bcond_with    i686

# CSM only possible on F21 (or using the SeaBIOS RPM from copr)
%bcond_without csm
%if %{with csm}
%global BUILD_OPTIONS     -D CSM_ENABLE
%endif


# More subpackages to come once licensing issues are fixed
Name:		OVMF
Version:	%{SVNDATE}svn%{SVNREV}
Release:	5%{?dist}
Summary:	EFI Development Kit II

# There are no formal releases from upstream.
# Tarballs are created with:

# svn export -r ${SVNREV} \
#     https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2 edk2-r${SVNREV}
# rm -rf edk2-r${SVNREV}/BaseTools
# rm -rf edk2-r${SVNREV}/ShellBinPkg
# rm -rf edk2-r${SVNREV}/FatBinPkg
# tar -cv edk2-r${SVNREV} | xz -6 > edk2-r${SVNREV}.tar.xz
Source0:	edk2-r%{SVNREV}.tar.xz

# see CryptoPkg/Library/OpensslLib/Patch-HOWTO.txt
Source1:        http://www.openssl.org/source/openssl-%{OpenSSLversion}.tar.gz

# svn export -r ${SVNFATREV} https://edk2-fatdriver2.svn.sourceforge.net/svnroot/edk2-fatdriver2/trunk/FatPkg/ edk2-fatdriver2-r${SVNFATREV}/FatPkg
# tar cv edk2-fatdriver2-r${SVNFATREV} | xz -6 > edk2-fatdriver2-r${SVNFATREV}.tar.xz
Source2:        edk2-fatdriver2-r%{SVNFATREV}.tar.xz

Patch1:		edk2-edksetup-no-basetools.patch
Patch2:		ovmf-cross.patch
Patch3:         build-fat-from-source.patch

Patch10:        0001-OvmfPkg-SmbiosPlatformDxe-install-tables-and-save-fi.patch
Patch11:        0002-OvmfPkg-SmbiosPlatformDxe-install-and-patch-default-.patch
Patch12:        0003-OvmfPkg-SmbiosPlatformDxe-install-and-patch-default-.patch
Patch13:        MdeModulePkg-TerminalDxe-add-other-text-resolutions.patch
Patch14:        OvmfPkg-PlatformPei-lifecycle-fixes-for-the-LockBox-area.patch
Patch15:        OvmfPkg-AcpiS3SaveDxe-do-not-load-if-S3-is-unsupported-di.patch
Patch16:        OvmfPkg-AcpiPlatformDxe-download-ACPI-tables-from-QEMU.patch
Patch17:        OvmfPkg-add-a-catch-all-match-for-PCI-devices-in-the.patch
Patch18:        OvmfPkg-PlatformPei-protect-SEC-s-GUIDed-section.patch
Patch19:        edk2-fix-BiosVideo-csm-pcd.patch

Patch100:       OvmfPkg-Don-t-build-in-QemuVideoDxe-when-we-have-CSM.patch
Patch101:       edk2-no-lock-umb.patch
Patch102:       edk2-disable-CSM-legacy-boot.patch

License:	BSD
Group:		Applications/Emulators
URL:		http://sourceforge.net/apps/mediawiki/tianocore/index.php?title=EDK2

# We need to build tools everywhere, but how is still an open question
# https://bugzilla.redhat.com/show_bug.cgi?id=992180
ExclusiveArch:	%{ix86} x86_64 %{arm}

BuildRequires:	python2-devel
BuildRequires:	libuuid-devel
BuildRequires:	/usr/bin/iasl
BuildRequires:  binutils-x86_64-linux-gnu gcc-x86_64-linux-gnu


%if %{with csm}
BuildRequires:	seabios-bin
%endif

BuildRequires:	edk2-tools%{?_isa} >= %{version}
%if %{with i686}
Requires:	OVMF-i686 = %{version}-%{release}
%endif
Requires:	OVMF-x86_64 = %{version}-%{release}

%description
OVMF is a sample UEFI firmware for QEMU and KVM.

%if %{with i686}
%package -n OVMF-i686
Summary:	UEFI firmware for 32-bit virtual machines
Group:		Applications/Emulators
License:        Modified BSD (non-free)
Buildarch:      noarch

%description -n OVMF-i686
OVMF is a project to enable UEFI support for Virtual Machines. This
package contains a sample 32-bit UEFI firmware for QEMU and KVM.
%endif

%package -n OVMF-x86_64
Summary:	UEFI firmware for 64-bit virtual machines
Group:		Applications/Emulators
License:        Modified BSD (non-free)
Buildarch:      noarch

%description -n OVMF-x86_64
OVMF is a project to enable UEFI support for Virtual Machines. This
package contains a sample 64-bit UEFI firmware for QEMU and KVM.


%prep
%setup -q -n edk2-r%{SVNREV}

# Ensure old shell and binary packages are not used
rm -rf EdkShellBinPkg
rm -rf EdkShellPkg
rm -rf FatBinPkg

# BaseTools come from the Fedora package
rm -rf BaseTools

# Secure boot mode requires unpacking the openssl sources and patches
%if %{with secure}
(cd CryptoPkg/Library/OpensslLib && tar xzf %{SOURCE1})
(cd CryptoPkg/Library/OpensslLib/openssl-%{OpenSSLversion} && patch -p0 < ../EDKII_openssl-%{OpenSSLversion}.patch)
(cd CryptoPkg/Library/OpensslLib && sh Install.sh)
%endif

# Unpack source for non-free FAT driver
xz -dc %{SOURCE2} | tar -xvf -
mv edk2-fatdriver2-r%{SVNFATREV}/FatPkg .

%patch1 -p1

export EDK_TOOLS_PATH=/usr/share/edk2
source ./edksetup.sh
%patch2 -p1
%patch3 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch100 -p1
%patch101 -p1
%patch102 -p1

# Done by %setup, but we do not use it for the auxiliary tarballs
chmod -Rf a+rX,u+w,g-w,o-w .


%build
export EDK_TOOLS_PATH=/usr/share/edk2
source ./edksetup.sh

cd OvmfPkg
%if %{with csm}
cp /usr/share/seabios/bios-csm.bin Csm/Csm16/Csm16.bin
%endif
%if %{with i686}
build -p OvmfPkg/OvmfPkgX64.dsc %{?BUILD_OPTIONS} %{?BUILD_OPTIONS_IA32} -a IA32 -b DEBUG -t GCC48 %{?jobs:-n %jobs}
%endif
build -p OvmfPkg/OvmfPkgX64.dsc %{?BUILD_OPTIONS} %{?BUILD_OPTIONS_X64} -a X64 -b DEBUG -t GCC48 %{?jobs:-n %jobs}

%install
mkdir -p $RPM_BUILD_ROOT%{_datadir}/OVMF
%if %{with i686}
install -m 0644 Build/OvmfIa32/DEBUG_GCC4?/FV/OVMF.fd $RPM_BUILD_ROOT%{_datadir}/OVMF/OVMFIa32.fd
%endif
install -m 0644 Build/OvmfX64/DEBUG_GCC4?/FV/OVMF.fd $RPM_BUILD_ROOT%{_datadir}/OVMF/OVMFX64.fd

%files
%doc FatPkg/License.txt

%if %{with i686}
%files -n OVMF-i686
%defattr(-,root,root,-)
%dir %{_datadir}/OVMF/
%{_datadir}/OVMF/OVMFIA32.fd
%endif

%files -n OVMF-x86_64
%defattr(-,root,root,-)
%dir %{_datadir}/OVMF/
%{_datadir}/OVMF/OVMFX64.fd

%changelog
* Mon Jun 23 2014 Paolo Bonzini <pbonzini@redhat.com> - 20140328svn15376-3
- Merge from rawhide
- Package EDK_TOOLS_PATH as /usr/share/edk2
- Package "build" and LzmaF86Compress too, as well as the new
  tools Ecc and TianoCompress.

* Wed Apr 30 2014 Paolo Bonzini <pbonzini@redhat.com> - 20140328svn15376-4
- Added edk2-disable-CSM-legacy-boot.patch

* Fri Apr 4 2014 Paolo Bonzini <pbonzini@redhat.com> - 20140328svn15376-3
- Added OvmfPkg-PlatformPei-protect-SEC-s-GUIDed-section.patch

* Mon Mar 31 2014 Paolo Bonzini <pbonzini@redhat.com> - 20140328svn15376-2
- Replace stopgap with correct fix in edk2-fix-BiosVideo-csm-pcd.patch
- Added OvmfPkg-add-a-catch-all-match-for-PCI-devices-in-the.patch

* Mon Mar 31 2014 Paolo Bonzini <pbonzini@redhat.com> - 20140328svn15376-1
- Refreshed patches (now needs ^M at end-of-line).
- Upgrade to r15376 for S3 support and other goodies.
- Added MdeModulePkg-TerminalDxe-add-other-text-resolutions.patch
- Added OvmfPkg-AcpiPlatformDxe-download-ACPI-tables-from-QEMU.patch
- Added S3 bugfixes from Laszlo.

* Fri Nov 15 2013 Paolo Bonzini <pbonzini@redhat.com> - 20131114svn14844-2
- Added OVMF builds using non-free FAT driver and SeaBIOS CSM.

* Thu Nov 14 2013 Paolo Bonzini <pbonzini@redhat.com> - 20131114svn14844-1
- Upgrade to r14844.
- Remove upstreamed parts of patch 1.

* Fri Nov 8 2013 Paolo Bonzini <pbonzini@redhat.com> - 20130515svn14365-7
- Make BaseTools compile on ARM.

* Fri Aug 30 2013 Paolo Bonzini <pbonzini@redhat.com> - 20130515svn14365-6
- Revert previous change; firmware packages should be noarch, and building
  BaseTools twice is simply wrong.

* Mon Aug 19 2013 Kay Sievers <kay@redhat.com> - 20130515svn14365-5
- Add sub-package with EFI shell

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 20130515svn14365-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu May 23 2013 Dan Horák <dan[at]danny.cz> 20130515svn14365-3
- set ExclusiveArch

* Thu May 16 2013 Paolo Bonzini <pbonzini@redhat.com> 20130515svn14365-2
- Fix edk2-tools-python Requires

* Wed May 15 2013 Paolo Bonzini <pbonzini@redhat.com> 20130515svn14365-1
- Split edk2-tools-doc and edk2-tools-python
- Fix Python BuildRequires
- Remove FatBinPkg at package creation time.
- Use fully versioned dependency.
- Add comment on how to generate the sources.

* Thu May 2 2013 Paolo Bonzini <pbonzini@redhat.com> 20130502.g732d199-1
- Create.
